# frozen_string_literal: true

module AbideDataProcessor
  module Processor
    class Logger
      LEVELS = {error: 1, warning: 2, info: 3, debug: 4}

      def initialize(level = :info, out = STDOUT, err = STDERR)
        @level = LEVELS[level]
        if @level.nil?
          raise ArgumentError, "Unknown log level at #{level}"
        end

        @out = out
        @err = err
      end

      def debug(message)
        if @level >= LEVELS[:debug]
          @out.puts(message)
        end
      end

      def inform(message)
        if @level >= LEVELS[:info]
          @out.puts(message)
        end
      end

      def warn(message)
        if @level >= LEVELS[:warning]
          @out.puts(message)
        end
      end

      def err(message)
        if @level >= LEVELS[:error]
          @err.puts(message)
        end
      end
    end
  end
end
